==> ruqola-1.5.2.tar.xz: ruqola-1.5.2/src/core/autotests/authenticationinfotest.cpp <==
/*
   Copyright (c) 2018-2021 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as published
   by the Free Software Foundation; either version 2 of the License or
   ( at your option ) version 3 or, at the discretion of KDE e.V.
   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "authenticationinfotest.h"
#include "authenticationinfo.h"
#include <QTest>
QTEST_GUILESS_MAIN(AuthenticationInfoTest)

AuthenticationInfoTest::AuthenticationInfoTest(QObject *parent)
    : QObject(parent)
{
}

void AuthenticationInfoTest::shouldHaveDefaultValue()
{
    AuthenticationInfo info;
    QVERIFY(info.iconName().isEmpty());
    QVERIFY(info.name().isEmpty());
    QCOMPARE(info.oauthType(), AuthenticationManager::Unknown);
}

void AuthenticationInfoTest::shouldAssignValue()
{
    AuthenticationInfo info;
    const QString name = QStringLiteral("name1");
    const QString iconname = QStringLiteral("iconname1");
    info.setName(name);
    info.setIconName(iconname);
    QCOMPARE(info.name(), name);
    QCOMPARE(info.iconName(), iconname);
    QCOMPARE(info.oauthType(), AuthenticationManager::Unknown);
}

void AuthenticationInfoTest::shouldBeValid()
{
    AuthenticationInfo info;
    QVERIFY(!info.isValid());

    const QString name = QStringLiteral("name1");
    const QString iconname = QStringLiteral("iconname1");
    info.setName(name);
    QVERIFY(!info.isValid());
    info.setIconName(iconname);
    QVERIFY(!info.isValid());

    info.setOauthType(AuthenticationManager::Twitter);
    QVERIFY(info.isValid());

    info.setIconName(QString());
    QVERIFY(info.isValid());

    info.setName(QString());
    QVERIFY(!info.isValid());
}

==> ruqola-2.4.1.tar.xz: ruqola-2.4.1/src/core/autotests/authenticationinfotest.cpp <==
/*
   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "authenticationinfotest.h"
#include "authenticationinfo.h"
#include <QTest>
QTEST_GUILESS_MAIN(AuthenticationInfoTest)

AuthenticationInfoTest::AuthenticationInfoTest(QObject *parent)
    : QObject(parent)
{
}

void AuthenticationInfoTest::shouldHaveDefaultValue()
{
    AuthenticationInfo info;
    QVERIFY(info.iconName().isEmpty());
    QVERIFY(info.name().isEmpty());
    QCOMPARE(info.oauthType(), AuthenticationManager::Unknown);
}

void AuthenticationInfoTest::shouldAssignValue()
{
    AuthenticationInfo info;
    const QString name = QStringLiteral("name1");
    const QString iconname = QStringLiteral("iconname1");
    info.setName(name);
    info.setIconName(iconname);
    QCOMPARE(info.name(), name);
    QCOMPARE(info.iconName(), iconname);
    QCOMPARE(info.oauthType(), AuthenticationManager::Unknown);
}

void AuthenticationInfoTest::shouldBeValid()
{
    AuthenticationInfo info;
    QVERIFY(!info.isValid());

    const QString name = QStringLiteral("name1");
    const QString iconname = QStringLiteral("iconname1");
    info.setName(name);
    QVERIFY(!info.isValid());
    info.setIconName(iconname);
    QVERIFY(!info.isValid());

    info.setOauthType(AuthenticationManager::Twitter);
    QVERIFY(info.isValid());

    info.setIconName(QString());
    QVERIFY(info.isValid());

    info.setName(QString());
    QVERIFY(!info.isValid());
}

#include "moc_authenticationinfotest.cpp"
